@@ -3,9 +3,9 @@ package Sah::Schema::filename::default_only_file_in_curdir;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-11-18'; # DATE
+our $DATE = '2023-11-23'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.024'; # VERSION
+our $VERSION = '0.025'; # VERSION
 
 our $schema = ["filename" => {
     summary => 'File name, defaults to only file in current directory (if there is one)',
@@ -15,6 +15,11 @@ This is like the `filename` schema but with a default value of "only file in the
 current directory". That is, if the current directory has a single plain file
 and nothing else.
 
+Difference with `filename::default_only_file_not_subdir_in_subdir` schema: the
+other schema ignores subdirectories. Thus, if a directory only contains `file1`
+and `subdir1`, then that other schema will return `file1` but this schema will
+not return a default value.
+
 Note: be careful when using this schema for actions that are destructive,
 because a user can perform those actions without giving an argument (e.g. in a
 `delete-file` script). It is safer to use this schema when performing a
@@ -40,7 +45,7 @@ Sah::Schema::filename::default_only_file_in_curdir - File name, defaults to only
 
 =head1 VERSION
 
-This document describes version 0.024 of Sah::Schema::filename::default_only_file_in_curdir (from Perl distribution Sah-Schemas-Path), released on 2023-11-18.
+This document describes version 0.025 of Sah::Schema::filename::default_only_file_in_curdir (from Perl distribution Sah-Schemas-Path), released on 2023-11-23.
 
 =head1 SYNOPSIS
 
@@ -163,6 +168,11 @@ This is like the C<filename> schema but with a default value of "only file in th
 current directory". That is, if the current directory has a single plain file
 and nothing else.
 
+Difference with C<filename::default_only_file_not_subdir_in_subdir> schema: the
+other schema ignores subdirectories. Thus, if a directory only contains C<file1>
+and C<subdir1>, then that other schema will return C<file1> but this schema will
+not return a default value.
+
 Note: be careful when using this schema for actions that are destructive,
 because a user can perform those actions without giving an argument (e.g. in a
 C<delete-file> script). It is safer to use this schema when performing a
