@@ -3,9 +3,9 @@ package Sah::Schema::pathname::unix::basename;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-11-18'; # DATE
+our $DATE = '2023-11-23'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.024'; # VERSION
+our $VERSION = '0.025'; # VERSION
 
 our $schema = ["str" => {
     summary => 'Filesystem base path name on a Unix system',
@@ -46,7 +46,7 @@ Sah::Schema::pathname::unix::basename - Filesystem base path name on a Unix syst
 
 =head1 VERSION
 
-This document describes version 0.024 of Sah::Schema::pathname::unix::basename (from Perl distribution Sah-Schemas-Path), released on 2023-11-18.
+This document describes version 0.025 of Sah::Schema::pathname::unix::basename (from Perl distribution Sah-Schemas-Path), released on 2023-11-23.
 
 =head1 SYNOPSIS
 
@@ -78,7 +78,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample invalid data
- $data = "foo\0";
+ $data = "";
  my $errmsg = $validator->($data); # => "Must match regex pattern \\A(?:[^/\\0]{1,255})\\z"
 
 Often a schema has coercion rule or default value rules, so after validation the
@@ -89,8 +89,8 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample invalid data
- $data = "foo\0";
- my $res = $validator->($data); # => ["Must match regex pattern \\A(?:[^/\\0]{1,255})\\z","foo\0"]
+ $data = "";
+ my $res = $validator->($data); # => ["Must match regex pattern \\A(?:[^/\\0]{1,255})\\z",""]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
